@@ -11,6 +11,8 @@ class Configuration:
     ledger_url: str
     ledger_id: str
     integration_metadata_path: str
+    integration_id: 'Optional[str]'
+    type_id: 'Optional[str]'
 
 
 def env(var: str, default: 'Optional[str]' = None) -> str:
@@ -40,7 +42,9 @@ def get_default_config() -> 'Configuration':
         health_port=envint('DABL_HEALTH_PORT', 8089),
         ledger_url=env('DABL_LEDGER_URL', 'http://localhost:6865'),
         ledger_id=env('DABL_LEDGER_ID', 'cloudbox'),
-        integration_metadata_path=env('DABL_INTEGRATION_METADATA_PATH', 'int_args.yaml'))
+        integration_metadata_path=env('DABL_INTEGRATION_METADATA_PATH', 'int_args.yaml'),
+        integration_id=os.getenv('DABL_INTEGRATION_INTEGRATION_ID'),
+        type_id=os.getenv('DABL_INTEGRATION_TYPE_ID'))
 
     LOG.info('Configuration: %r', asdict(config))
 
